@@ -36,6 +36,8 @@ from DateTime import DateTime
 import Permissions
 from config import PROJECTNAME, UNIQUE_ID, TOOLNAME
 
+from Products.PloneInvite import PloneInviteMessageFactory as _
+
 class UsedInviteError(Exception):
     pass
 
@@ -52,18 +54,18 @@ class PloneInvite(UniqueObject, ObjectManager, SimpleItem, ActionProviderBase,
 
     meta_type = TOOLNAME
     id = UNIQUE_ID
-    title = 'Allows users to invite new users'
+    title = _(u'Allows users to invite new users')
     
     _actions = (
         ActionInformation(id='invite',
-                          title='Invite',
+                          title=_(u'Invite'),
                           action=Expression( text='string:${portal_url}/invite_form'),
                           condition=Expression( text='python:member and len(portal.plone_invite.getInvitesUser(used=0, sent=0))'),
                           permissions=(Permissions.InvitePortalUsers,),
                           category='user',
                           visible=1),
         ActionInformation(id='generate_invites',
-                          title='Give invitations',
+                          title=_(u'Give invitations'),
                           action=Expression( text='string:${portal_url}/user_invites'),
                           condition=Expression( text='python:member and not checkPermission("Manage portal", context)'),
                           permissions=(Permissions.GeneratePortalInvites,),
@@ -149,7 +151,7 @@ class PloneInvite(UniqueObject, ObjectManager, SimpleItem, ActionProviderBase,
         """
         obj = self.invites.get(invitecode, None)
         if obj is None or obj.used:
-            raise UsedInviteError('Invalid invite code.')
+            raise UsedInviteError(_(u'Invalid invite code.'))
         obj.use(recipient)
 
     security.declarePublic('getJoinFormAddress')
@@ -212,12 +214,12 @@ class PloneInvite(UniqueObject, ObjectManager, SimpleItem, ActionProviderBase,
                 obj = self.invites.get(invitecode, None)
                 obj.enforce()
                 return invitecode
-            raise InviteError, "You have no invitations"
+            raise InviteError, _(u"You have no invitations")
 
         for invite in invites:
             if not invite['enforce_address']:
                 return invite['id']
-        raise InviteError, "You have no invitations"
+        raise InviteError, _(u"You have no invitations")
         
     security.declareProtected(Permissions.ManageMemberInvites, 'getInvitesUser')
     def getInvitesUser(self, sent=None, used=None, enforce_address=None):
@@ -336,7 +338,7 @@ class InviteToken(CatalogPathAware, SimpleItem):
         the new user.
         """
         if self.expired():
-            raise InviteError('Invite code has expired.')
+            raise InviteError(_(u'Invite code has expired.'))
             
         if not self.used:
             self.recipient = recipient
@@ -344,7 +346,7 @@ class InviteToken(CatalogPathAware, SimpleItem):
             self.used = True
             self.reindex_object()
         else:
-            raise UsedInviteError('Invite code already used by %s.' % self.recipient)
+            raise UsedInviteError(_(u'Invite code already used by %s.') % self.recipient)
             
     security.declareProtected(Permissions.ManagePortalInvites, 'enforce')
     def expired(self):
@@ -378,7 +380,7 @@ class InviteToken(CatalogPathAware, SimpleItem):
             self.xdate = self.sdate + days 
             self.reindex_object()
         else:
-            raise UsedInviteError('Invite code already sent to %s.' % self.sent_address)
+            raise UsedInviteError(_(u'Invite code already sent to %s.') % self.sent_address)
     
     security.declarePrivate('_invitedict')
     def _invitedict(self):
