@@ -12,6 +12,8 @@
 ## License along with this library; if not, write to the Free Software
 ## Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
+from zope.i18nmessageid import MessageFactory
+PloneInviteMessageFactory = MessageFactory('PloneInvite')
 
 from Products.CMFCore import utils, DirectoryView
 from config import PROJECTNAME, GLOBALS
