@@ -1,3 +1,4 @@
+from Products.PloneInvite import PloneInviteMessageFactory as _
 from Products.PloneInvite.Permissions import GeneratePortalInvites, \
     InvitePortalUsers, ManageMemberInvites, ManagePortalInvites, AddPortalUser
 
@@ -17,7 +18,7 @@ SET_PORTAL_PERMISSIONS= (
     )
 
 SET_CONTROL_PANEL = (
-    ('UserInvites', 'Member Invitations', 'string:${portal_url}/user_invites', 
+    ('UserInvites', _(u'Member Invitations'), 'string:${portal_url}/user_invites', 
     '', ManagePortalInvites, 'Products', 1, 'UsersGroups',
     'group.gif', ''),
     )
